---
jupyter:
  kernelspec:
    display_name: Python 3
    language: python
    name: python3
---

This cell uses no particular cell marker

$$
\begin{align}
\dot{x} & = \sigma(y-x)\\
\dot{y} & = \rho x - y - xz \\
\dot{z} & = -\beta z + xy
\end{align}
$$


This cell uses no particular cell marker, and a single slash in the $\LaTeX$ equation

$$
\begin{align}
\dot{x} & = \sigma(y-x) \
\dot{y} & = \rho x - y - xz \
\dot{z} & = -\beta z + xy
\end{align}
$$


This cell uses the triple quote cell markers introduced at https://github.com/mwouts/jupytext/issues/305

$$
\begin{align}
\dot{x} & = \sigma(y-x)\\
\dot{y} & = \rho x - y - xz \\
\dot{z} & = -\beta z + xy
\end{align}
$$
